pm4py.objects.conversion.log.variants package
=============================================

Submodules
----------

pm4py.objects.conversion.log.variants.df\_to\_event\_log\_1v module
-------------------------------------------------------------------

.. automodule:: pm4py.objects.conversion.log.variants.df_to_event_log_1v
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.objects.conversion.log.variants.df\_to\_event\_log\_nv module
-------------------------------------------------------------------

.. automodule:: pm4py.objects.conversion.log.variants.df_to_event_log_nv
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.objects.conversion.log.variants.to\_data\_frame module
------------------------------------------------------------

.. automodule:: pm4py.objects.conversion.log.variants.to_data_frame
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.objects.conversion.log.variants.to\_event\_log module
-----------------------------------------------------------

.. automodule:: pm4py.objects.conversion.log.variants.to_event_log
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.objects.conversion.log.variants.to\_event\_stream module
--------------------------------------------------------------

.. automodule:: pm4py.objects.conversion.log.variants.to_event_stream
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.objects.conversion.log.variants
   :members:
   :undoc-members:
   :show-inheritance:
